pub struct FrequentItemset { /* private fields */ }Expand description
A frequent itemset and its support over the transaction matrix.
items is the set of item (column) indices in ascending order; support is the
fraction of transactions that contain every item in the set, in [0, 1].
Implementations